@@ -1,9 +1,11 @@
 package WebService::Raygun;
-$WebService::Raygun::VERSION = '0.022';
+$WebService::Raygun::VERSION = '0.023';
 # VERSION
 
 =head1 NAME
 
+=for HTML <a href="https://travis-ci.org/heytrav/raygun4perl"><img src="https://travis-ci.org/heytrav/raygun4perl.svg?branch=master"></a>
+
 WebService::Raygun - Connect to the Raygun.io API
 
 =head1 SYNOPSIS
@@ -90,6 +92,9 @@ Constructs the actual message. See this class for a better description of the fi
 
 =cut
 
+use strict;
+use warnings;
+
 1;
 
 __END__
